Colombo
Kandy
Gampaha
Ella
Bandarawela
Badulla
Jafna
Galle
Matara
Hatton
Panadura
Maradana
Kaluthara
Hambanthota
Haputhale
Diyatalawa
Monaragala
Rathnapura
Kurunagela
Colombo2
Colombo3
Colombo4
Colombo5
Colombo6
Colombo7
Colombo8
Colombo10
Colombo11
Colombo12
Colombo13
Colombo14
Colombo15
Mount Lavinia
Kesbewa
Moratuwa
Maharagama
Ratnapura
Negombo
Sri Jayewardenepura Kotte
Kalmunai
Trincomalee
Jaffna
Athurugiriya
Weligama
Kolonnawa
Puttalam
Kalutara
Bentota
Matale
Mannar
Pothuhera
Kurunegala
Mabole
Hambantota
Oruwala
Akkaraipattu
Ampara
Anuradhapura
Balangoda
Batticaloa
Chavakachcheri
Chilaw
Dambulla
Dehiwela-Mount Lavinia
Embilipitiya
Eravur
Gampola
Happutalle
Homagama
Kattankudy
Kegalle
Kinniya
Kuliyapitiya
Mahiyanganaya
Mawathagama
Mihintale
Mulleriyawa
Nuwara Eliya
Padukka
Polonnaruwa
Point Pedro
Thambiluvil
Valvettithurai
Vavuniya
Vijitapura


Ayesha
Nirosha
Nethuli
Supuni
Kanchana
Chamari
Kushani
Yohani
Udari
Sadali
Nimali 
Yomali 
Amali 
Kumari 
Bhagya
Tharushi
Sachini
Hiruni
Janani
Rashmi
Thilini
Samadhi
Amanda
Nethmi
Chathu
Nipuni
Sanduni
Upeksha
Sara
Shehara
Harshani
Ama
Gayani
Dinithi
Hansi
Senuri
Hashani
Kalpani
Piyumi
Dewmini
Saumya
Shashini
Yashodha
Chathuri
Isuri
Kaushi
Sandali
Nimesha
Hansani
Sachi
Nayani
Hansika
Priya
Dinusha
Shani
Shehani
Supuni
Nathasha
Anu
Shashi
Kasuni
Jayani
Vinodi
Iresha
Anjalee
Alexcia
Amaya
Sarah
Aysha
Himasha
Piumi
Vishaka
Geethma
Nadeesha
Savindi
Dhanu
Tharindi
Natasha
Chathuni
Anuradha
Vishmi
Madu
Shalini
Wathsala
Pawani
Sandani
Imesha
Ann
Sewwandi
Sithmi
Kavindi
Nimasha
Roshani
Navoda
Dilini
Kalani
Navodya
Sithara
Noofa
Anjali
Sanju
Shakya
Visuri
Kaveesha
Maleesha
Sathya
Nishi
Mahesha
Malki
Dilki
Ishka
Mihiransi
Chamudi


from __future__ import unicode_literals
from os.path import abspath, join, dirname
import random

full_path = lambda filename: abspath(join(dirname(__file__), filename))

#path = os.path.abspath("new.py")
#print(path)
def name_array(file):
    with open(file) as fp:
        new_list = []
        for line in fp:
            new_list.append(line.strip())
    return new_list


file = full_path("male_first_names.py")
print(file)
male_names_file = name_array(file)

file = full_path("female_first_names.py")
female_names_file = name_array(file)

file = full_path("last_names.py")
last_names_file = name_array(file)

file = full_path("home_address.py")
home_address_file = name_array(file)

file = full_path("city.py")
city_name_file = name_array(file)


def queen():
    result = f"['Avihinsaka uwathy','Nihada Mawatha ','Palu Niwahana']"
    return result



def female_name():
    result = f"[{random.choice(female_names_file)} {random.choice(last_names_file)}]"
    return result



def female_name_address():
    result = f"[{random.choice(female_names_file)} {random.choice(last_names_file)},{random.choice(home_address_file)},{random.choice(city_name_file)}]"
    return result


def male_name():
    result = f"[{random.choice(male_names_file)} {random.choice(last_names_file)}]"
    return result



def male_name_address():
    result = f"['{random.choice(male_names_file)} {random.choice(last_names_file)}','{random.choice(home_address_file)}','{random.choice(city_name_file)}']"
    return result





import random
from .Data import *


# prastha_pirulu
def prasthapirulu():
    return random.choice(Prastha_Pirulu_List)


# prastha_pirulu
def pp():
    return random.choice(Prastha_Pirulu_List)


# theravili
def theravili():
    current_quiz = random.choice(theravili_List)
    # Display the quiz question without the answer
    
    print(f"Quiz: {current_quiz.split('-')[0]}")

    # Wait for user input
    input("Press Enter to answer..")

    # Display the answer
    print(f"Answer: {current_quiz.split('-')[1].strip()}")


# thun_theravili
def thun_theravili():
    current_quiz = random.choice(thun_theravili_List)
    # Display the quiz question without the answer
    
    print(f"Quiz: {current_quiz.split('-')[0]}")

    # Wait for user input
    input("Press Enter to answer..")

    # Display the answer
    print(f"Answer: {current_quiz.split('-')[1].strip()}")


# thun_theravili shorts
def thun():
    current_quiz = random.choice(thun_theravili_List)
    # Display the quiz question without the answer
    
    print(f"Quiz: {current_quiz.split('-')[0]}")

    # Wait for user input
    input("Press Enter to answer..")

    # Display the answer
    print(f"Answer: {current_quiz.split('-')[1].strip()}")





# Prastha_Pirulu_List
Prastha_Pirulu_List = [

"අනුන්ට කල දේ තමන්ට පලදේ - අනුන් වෙනුවෙන් කල නරක ක්‍රියාවක ප්‍රතිඵල තමන් වෙත ද ලැබිය හැක",
"ඉවසීමෙන් සැනසීම ලැබේ - ජයග්‍රහණ ලබාගැනීමට නම් ඉවසීමෙන් කටයුතු කල යුතුය",
"ඉක්මන් කොටයි - වැඩි හදිස්සියක් හොඳ නැත",
"උගුරට හොරා බෙහෙත් බීම - තමන් ව තමන් විසින් ම රවටා ගැනීම",
"කබලෙන් ළිපට වැටුනා වගේ - විපතට පත්වූ අයෙක් ඊටත් වඩා විපතකට පත් වීම",
"අතීසාරෙට අමුඩේ ගැහුවා වගේ - නිෂ්ඵල කාර්යයක නිරත වීම",
"කකුළුවා නටන්නේ දිය රත්වෙන තුරුලු - විපතකට පත්වීමට පෙර තාවකාලික සතුටක් ලැබීම",
"ගැරඬි මරා පව් පුරවා ගැනීම - අහිංසකයන් ට හිරිහැර කිරීම සුදුසු නොවන බව",
"ගිලී මලේ ඇත දත සුද්දෝ - ඉතා දුර්ලභ මිනිසුන් සිටීම",
"දී කිරට බළලුත් සාක්කිලු - කවුරුත් වාසි ඇත පැත්ත ට එකතු වේ",
"නරියා හුවෙන් හඳුනා ගත හැකිය - කපටියා කතාවෙන් හඳුනා ගත හැකිය",
"නයාට අඳුකොළ වගෙයි - දැකීමට කොහෙත්ම අකමැති වීම",
"නටන්නට බැරි කෙනා පොලව ඇදයි කීම - අදක්ෂයා තම බැරිකම වහගැනීමට වෙන දෙයක වරදක් කීම",
"පනින්නට පෙර සිතා බලනු - යමක් කිරීමට පෙර කල්පනා කර බැලිය යුතුයි",
"පුහුල් හොරා කරෙන් දැනේ - බාහිර ඉරියවු වලින් වරදකරු සොයා ගැනීම",
"පවට පින් දෙන්න බෑ - බලහත්කාරයෙන් කෙනෙකුට යහපතක් කල නොහැකිය",
"පිරුණු කලේ දිය නොසැලේ - උගතුන් නිහතමානී වේ.",
"පුවක් ගහෙන් බහින්නා වගේ - යම්දෙයක් ඉතා පහසුවෙන් සහ ඉක්මනින් කිරීම",
"බීරි අලියා ට වීනා වයනවා වගේ - අවවාද නොඅසන්නෙකුට අවවාද කිරීම",
"දිලිසෙන සියල්ල රත්තරන් නොවේ - බාහිර ඔපයට නොරැවටිය යුතුයි",
"අටුව කඩා පුටුව සෑදුවා වාගේ - වටින දෙයක් විනාශ කර නොවටිනා බාල ක්‍රියා කිරීම",
"පිරුණු කළේ දිය නොසැලේ. - උගතුන් ඉතා නිහතමානිව සිටි අනුවණයි පුරසාරමෙන්කල් ගෙවයි",
"වක්කඩේ හකුරු හැංගුවා වාගේ - යම් දෙයක් ප්‍රවේසම් කිරීමට ඊට නොගැළපෙන ස්ථානයක සැඟවීමෙන් එය විනාශ වීම",
"ගමරාළ දිව‍්‍ය ලෝකේ ගියා වගේ.",
"ගමරාළගේ වංගෙඩිය වා‍ගේ - සෑම දෙයකටම පාවිච්චි වන භාණ්ඩයකට මේ නම යෙදේ",
"අබරා (අබරං) සිල් ගත්තා වා‍ගේ. (ගමරාළ සිල් ගත්තා වාගේ.)",
"ආඬි හත්‍ දෙනාගේ කැද හැලිය ‍වාගේ.-එකිනෙකා රැවටීමට ගොස් තමාම රැවටීම.",
"පනින රිලවුන්ට ඉනිමං බදින්නා වා‍‍ගේ.-උරුමාවෙන් යමක් කරන වර්ගයාට අමටර උදව් කිරීම.",
"කපන්න බැරි අත ඉඹිනවා වාගේ.-පළිගැනීමට නොහැකි වූ විට ව්‍යාජ ලෙස පිළිගැනීම.",
"නටන්න බැරි මිනිහා පො‍ළව ඇදයි කිව්වා වාගේ.",
"ගහෙන් වැටුන මිනිහට ගොනා ඇන්නා වාගේ.",
"වත්ත බද්දට දී ඇස්සට දත නියවනවා වාගේ.",
"වැටත් නියරත් ගොයම් කා නම් කාට පවසම් ඒ අමාරුව.",
"ලූලා නැති ව‍ලට කනයා පණ්ඩිතයා.",
"හිත ඇත්නම් පත කුඩාද.",
"හිඟන්නාගේ පාත්තරේට හෙනහුරා වැටුනා වා‍ගේ.",
"හිඟන්නාගේ තුවාලය වාගේ.",
"කම්මලේ ඉන්න බල්ලා වාගේ.-නිතර ම කරදර පැමිණීමෙන් ජීවිතය එයට හුරු වේ.",
"බුරන බල්ලා හපා නොකයි.",
"බල්ලට ඇති වැඩකුත් නෑ හිමින් ගමනකුත් නෑ.",
"බල්ලා පිඳුරු කන්නෙත් නෑ කන ගොනාට දෙන්නෙත් නෑ.",
"බල්ලෙක් බිරුවට කන්දක් පාත් වේද?",
"ගලේ පහරපු බළලා වාගේ.",
"දී කිරට බළල්ලුත් සාක්කිලු.",
"බළලුන් ලවා කොස් ඇට බාවනවා වාගේ.",
"වඳින්න ගිය දේවාලේ ඉහේ කඩා වැටුනා වාගේ.",
"පනින්න පෙර සිතා බලනු.",
"ඌරන් කැකුණ තලනකොට හබන් කුකුළන්ට ජය මඟුල්.",
"හැමදාම දකින කුකුළගේ කරමලේ සුදු වුණා වාගේ.",
"උඩ පැන්නොත් බිම වැටේ.",
"ඇඟිල්ලේ තරමට ඉඳිමෙන්න.",
"ගඟට කැපුව ඉනි වගේ.",
"කළුවා මාරපන ගියා වගේ.",
"උගුරට හොරා බෙහෙත් බොනවා (කනවා) වාගේ.",
"හොරාගෙ අම්මගෙන් පේන අහන‍වා වාගේ.",
"දිළිසෙන සියල්ල රත්තරං නොවේ.",
"අතීසාරෙට අමුඩෙ ගැහුවා වාගේ.",
"කබලෙන් ලිපට වැටුනා වාගේ.",
"කිඹුලා කන එක ඉවසන්න පුළුවන් කොහිල කටු ඇනෙන එක තමයි ඉවසන්න බැරි.",
"ගිලීමලෙත් ඇත දත සුද්දෝ.",
"විෂ්ණු දෙයියෝ බටකොළ කෑවා වාගේ.",
"ඉහේ ඇම්මට කොට්ටෙ මාරුකලා වාගේ.",
"පරංගියා කෝ‍ට්ටේ ගියා වාගේ.",
"ඉඟුරු දීලා මිරිස් ගත්තා වාගේ.",
"අන්දරේ සීනි කෑවා වාගේ.",
"ඉත්තෑවාගේ ගෙට කබල්ලෑවා රිංගුවා වාගේ.",
"ඉස්සරින් ආපු කනට වඩා පස්සේ ආපු අඟ ලොකු වුනා වාගේ.",
"නටපු නැටුමකුත් නෑ, බෙරේ පළුවකුත් නෑ.",
"කන්න හිතුනම කබරගොයත් තලගොයා වෙනවලු.",
"උණහපුළුවාට උගේ පැටියා මැණිකක්ලු.",
"මුහුද හත් ගව්වක් තියා අමුඩ ගහන‍වා ව‍ාගේ.",
"කොකාට වාරයක් නම් තිත්තයාටත් වාරයක් එනවලු.",
"කොකා බක තපස් රැක්කා වාගේ.",
"කන කොකාගේ සුද පේන්නේ ඉගිලෙනකොටලු.",
"ඉබ්බා අහසින් ගියා වාගේ.",
"ඉබ්බා දියේ දැම්මා වාගේ.",
"පෙරලෙන ගලේ පාසි නොබැදේ.",
"ගල හොඳනම් අඹරන කහ මක් වේද?",
"කතාව දෝලාවෙන් ගමන පයින්.",
"කොහොඹ ගහට කරවිල වැල ගියා ව‍ගේ.",
"කටුස්සාගේ කරේ රත්තරං බැන්දා වාගේ.",
"මරණ තුනක් ඇති මිනිහෙක් පැණි කෑවා වාගේ.",
"මඩ සෝදා ගත් කළ ගොවියා රජකමටත් සුදුසුය.;",
"කැකිල්ලේ රජ්ජුරුවන්ගේ නඩු තීන්දුව වගේ.",
"හැදෙන ගහ දෙපෙත්තෙන් දැනේ.",
"අඬන්න ඉන්න මිනිහට ඇඟිල්ලෙන් අනින්නා වාගේ.",
"උරුලෑවා ගිය පාර වගේ.",
"අබුද්දස්ස කාලේ ලබුත් තිත්තයිලු.",
"අ‍‍ඟේ ඉඳං කන කන‍වා වාගේ.",
"ගිනිපෙනෙල්ලෙන් බැට කාපු එකා කණාමැදිරි එළියටත් බයයිලු.",
"වෙහෙර ගිලපු එවුන්ට අග්ගලා කජ්ජක්ද?",
"කන කැස්බෑවා විය සිදුරෙන් අහස බලන්නා වාගේ.",
"පුහුල් හොරා කරෙන් දැනේ.",
"ගලෙන් පට්ට ගන්නවා වාගේ.",
"දත් නැති දා උක් දඬු ගිනි තපින්නද?",
"ලැජ්ජා නැතිකම මහමුදලි කමටත් වඩා ලොකුයිලු.",
"ඇටි කෙහෙල් කාපු උගුඩුවා වාගේ.",
"ඉබ්බාගෙන් පිහාටු ඉල්ලනවා වාගේ.",
"පල නොකියා පලා බෙදන්නා වාගේ.",
"ගහ දන්න මිනිහට කොළ කඩා පාන්නා වාගේ.",
"නංගි පෙන්නලා අක්කා දෙනවා වාගේ.",
"ගහේ කටු උල් කරන්න ඕන ද?",
"දාහට අරං සීයට දුන්නා වාගේ.",
"ඇතා වැහැරුනත් කොරහේ නාවන්නට බැරුවා වාගේ.",
"අත්හැරෙන දීගේ හෙවනැල්ලත් ඇදයිලු.",
"අබ කෑ මිනිහගේ මොළේ දනවා වාගේ.",
"අතු කඩා මොර කන්නා වාගේ.",
"අනුන්ගේ පහනින් එළිය බලනවා වාගේ.",
"පෙරහැරේ යන අලි කොට අදින්නේ නැතුවා වාගේ.",
"යුද්දෙට නැති කඩුව කොස් කොටන්නද?",
"වඩුවගේ ගෙදර පුටුව නෑ වාගේ.",
"උණු හින්දා බොන්නත් බෑ කිරි හින්දා හලලත් බෑ.",
"එළිපත්ත උඩ ඉන්න බළලා වාගේ.",
"රයිගමයයි ගම්පලයයි වාගේ.",
"වන්සේ කබල් ගාන්නා වාගේ.",
"ඌරගේ මාළු ඌරගේ ඇගේම තියලා කපනවා වාගේ.",
"කිතුලට ගිය එකාටත් කියන්න දේවල් තිබුනලු.",
"බල්ලගේ වැඩේ බූරුවා කරන්න ගියා වාගේ.",
"අන්ධයෝ අලියාගේ හැඩ කිව්වා වාගේ.",
"ගඟෙන් දිය බී මුහුදට ආවඩන්නා වාගේ.",
"උරුලෑව බළලෙකු කරන්නට බැරි වීම - ඇතැම් වැඩ කල නොහැකි වීම",
"කිරි ගහට ඇනීම - හරියටම හරි",
"කිඹුල් කඳුළු හෙලීම - බොරුවට අඬනවා",
"කබරයාට තලනවා - නිෂ්පල දඬුවමක් දීම",
"පරංගියා කෝට්ටේ ගියා වාගෙයි - කෙටි මගක් තිබියදී දිගු මගකින් යාම (සරල ක්‍රියාවක් මහා පරිමාණයෙන් කරන්නට යෑම)",
]

theravili_List = ["ගින්නක් නැතුව නගින දුම - මීදුම",
"කැලයේ නැති ඉන්න - යකඩ ඉන්න ",
"ඔක්කොගෙම මල්ලි - කොත්ත මල්ලි",
"ඔක්කොගෙම අක්කා - වට්ටක්කා",
"තනි කකුලෙන් ඉන්න සුද්දා - හත්ත",
"අහසට දිග රිට - වැහි බින්දුව",
"ඔබේ සාක්කුවේ නොතිබිය යුතු දෙයකි - හිලක්",
"අගුරු කකා වතුර බිබී කොළඹ දුවන යකඩ යකා - දුම්රිය",
"දෙයියන්ගේ දුන්න  - දේදුන්න",
"නැට්ට නැති ගෙඩිය - බිත්තර ගෙඩිය",
"ගහක් උඩින් මුවෙක් පැන්නා  - කෙහෙල් මුව",
"කිසිම කෙනෙකු නොයා යුතු මග - නොමග",
"කාන්තාරයේ නැව  - ඔටුවා",
"වඩු බාස් ලග තියෙන රට - බුරුමය",
"කටු නැති කැලේ අැට නැති සතා- උකුණා",
"කිසිවෙකු නොකියවන පොත - ඉලපොත",
"ගස් වල නැති මල - කම්මල",
"ගහක් උඩ ගෙඩියක් ගෙඩියක් උඩ ගහක් - අන්නාසි",
"අතු අග පිපෙන ලිය - අරලිය",
"දවල් කනා - බකමූණා",
"වළලද්දි කොළ පාටයි ගොඩ ගද්දි කහ පාටයි - කෙසෙල් කැන",
"ගෙදර ඉන්න කිඹුලගේ මල්ලි - හූනා",
"ලේ කිව්වට රතුත් නෑ නා කිව්වට දළුත් නෑ  - ලේනා",
"බෝතලේට දාන්න බැරි පැණි - කොම්පැණි",
"කන්න දෙනකොට ජීවත් වෙනවා වතුර දෙනකොට මැරෙනවා - ගින්දර",
"කන්නෙත් නෑ බොන්නෙත් නෑ ගෙදර දොරේ වැඩ කරනවා - යතුර",
"කාගෙත් අයියා - දහයියා",
"පුංචි ළිදේ වතුර රසයි - තැඹිලි",
"අලියා නොයන මග  - ඉනිමග",
"කැලේට පාන - ගද පාන",
"අලියා නොකන දල්ල - ගිනි දැල්ල",
"සුදු මහත්තයා හොටු පෙරාගෙන - ඉටි පන්දම",
"සුදු මහත්තයා කළු තොප්පියක් දාගෙන - ගිනි කූර",
"වත්ත පහළ ළමයින් අඩවන්නා - කොච්චි කරල",
"බෙල්ලෙන් අල්ලලා මුල්ලෙන් තියනවා - හිරමනය",]


thun_theravili_List =["රේප වතුර - රේප නම් කොම්බු , වතුර නම් ජලය = කොම්බු ජලය , ජම්බු කොළය",
"කෙලවර හපහපා - කෙලවර නම් කොණ , හපහපා නම් කකා = කොණ කකා  , කණ කොකා",
"මෝඩ රුකුල් - මොඩ නම් ගොං  , රුකුල් නම් අඩ = ගොං අඩ , අංගොඩ",
"සරුංගල් නූල - සරුංගල් නම් කයිට් , නූල නම් ලණුව = කයිට් ලණුව , ලයිට් කණුව",
"අහුර හූම් හූම් - අහුර නම් පිඩ , හූම් හූම් නම් බස්සා = පිඩ බස්සා , බඩ පිස්සා",
"වගේ වෙල - වගේ නම් වැනි , වෙල නම් වෙල් = වැනිවෙල් , වෙනිවැල්",
"පලතුරු තවාන - පලතුරු නම් බෙලි , තවාන නම් ගොල්ල = බෙලි ගොල්ල , ගොළු බෙල්ල",
"වග රිද්මය - වග නම් කරුණ , රිද්මය නම් තාලය = කරුණ තාලය , තරුණ කාලය",
"කාරිය බලන් - කාරිය නම් වැඩ , බලන් නම් බල = වැඩ බල , බඩ වැල",
"උදරයේ අසිපත් - උදරයේ නම් බඩේ , අසිපත් නම් කඩු = බඩේ කඩු  , කඩේ බඩු",
"වස මැහි - වස නම් වහ , මැහි නම් මැස්ස = වහ මැස්ස , මහ වැස්ස",
"කෝකි කටුවා - කෝකි නම් කුක් , කටුවා නම් කට්ටා = කුක් කට්ටා , කක් කුට්ටා",
"රත්තරං වට - රත්තරං නම් රන් , වට නම් ගෝල = රන් ගෝල , ගොන් රාල",
"පිලිකුල් කකුල - පිලිකුල් නම් ජරා , කකුල නම් පය = ජරා පය , පරා ජය",
"මහත්තයා වහලේ- මහත්තයා නම් සර් , වහලේ නම් පලය = සර්පලය , පාර්සලය",
"පවතින පුත්‍රයා- පවතින නම් පවත් , පුත්‍රයා නම් පුත් = පවත් පුත් , පුවත් පත්",
"කාලය පැවරීම- කාලය නම් කල් , පැවරීම නම් දෙනවා = කල් දෙනවා , දෙල් කනවා",
"රැකවල් පැසුනේ- රැකවල් නම් මුර , පැසුනේ නම් ඉදුනේ = මුර ඉදුනේ , ඉර මුදුනේ",
"පොළොව පැත්ත- පොළව නම් මිහි , පැත්ත නම් මිට = මිහි පිට , පිහි මිට ",
]


while True:
    n = input("Height: ")
    if n.isdigit():
        num = int(n)
        if num > 0 and num <= 108:
            break

#make use of i which is changing !
for i in range(num):
    # print spaces first
    print(" " * (num-1-i), end="")
    # print hashes
    print("*" * (i + 1), end="")

    # print middle spaces
    print("  ", end="")
    # print hashes again
    print("*" * (i + 1))


Siripala
Bandara
Wedikkara
Abekon
Jayasinha
Karunarathne
sangakkara
jayawardene
samarawekrama
jayasuriya
Abepala
Saparamadu
Silva 
Perera 
Mendis 
Gamage
Perera  
Fernando  
De silva  
Bandara  
Kumara  
Dissanayake    
Gamage  
Liyanage  
Jayasinghe  
Ranasinghe  
Herath  
Weerasinghe  
Peiris  
Rathnayake  
Wickramasinghe  
Wijesinghe  
Hettiarachchi  
Nanayakkara    
Rajapaksha  
Mendis  
Pathirana  
Ekanayake  
Gunasekara  
Dias  
Sampath  
Amarasinghe  
Ratnayake  
Chathuranga  
Senanayake  
Samarasinghe  
Lakmal  
Munasinghe  
Rodrigo  
Seneviratne  
Rathnayaka  
Edirisinghe  
Jayawardena  
Fonseka    
Gunawardana      
Karunaratne  
Jayaweera  
Jayasekara  
Ranaweera  
Jayawardana  
Jayasuriya    
Alwis  
Rajapakse  
Karunarathna  
Dissanayaka  
Jayakody  
Samarakoon  
Kariyawasam  
Cooray  
Karunarathne    
Abeysinghe  
Rupasinghe  
Sandaruwan  
Weerakoon  
Jayalath  
Gunasekera  
De alwis    
Jayasundara  
Tennakoon  
Weerasekara  
Vithanage  
Subasinghe  
Kumarasinghe  
Hewage  
Gunarathna  
Gunaratne  
Prasanna  
Samaraweera  
Athukorala  
Maduranga  
Wijeratne  
Wijekoon  
Gunathilaka    
Pushpakumara  
Priyadarshana  
Samaranayake  
Lanka  
Jayathilaka  
Siriwardana  
Gunathilake  
Dassanayake  
Senevirathne  
Pradeep    
Yapa  
Priyankara  
Wijesekara  
Desilva  
Indika    
Attanayake  
Ranathunga  
Basnayake  
Senaratne  
Withanage      
Wijerathne    
Sri Wijesinghe  
Kannangara  
Siriwardena  
Adikari  
Jayarathna    
Kodithuwakku    
Senevirathna      
Wanniarachchi  
Wijerathna    
Rajakaruna  
Jayathilake  
Gunarathne  
Ranatunga    
Abeykoon  
Karunanayake  
Tharanga  
Jayasooriya  
Abeywickrama  
Senarath  
Wijesundara  
Guruge  
Jayasekera  
Balasuriya    
Samarawickrama  
Weerakkody  
Chandrasiri  
Marasinghe    
Priyadarshani  
Kuruppu  
Atapattu  
Madushani  
Wijesuriya  
Weerasooriya  
Kaluarachchi  
Wijesooriya  
Kodikara  
Balasooriya  
De zoysa    
Jayaratne  
Alahakoon  
Tissera  
Amarasekara  
Darshana  
Senarathna  
Kulathunga  
Thilakarathna    
Rajapakshe  
Dharmasena  
Sandamali  
Raj  
Jayawickrama  
Gunawardhana  
Ekanayaka    
Suraweera      
Jayarathne  
De mel    
Chandrasekara  
Senarathne  
Ranawaka    
Thilakarathne      
Bandaranayake  
Anthony  
Kulatunga  
Mudalige  
Soysa      
Samarasekara  
Dasanayaka          
Withana  
Liyanaarachchi      
Hettige    
Pereira  
Pieris      
Gurusinghe    
Rajaratnam              
Caldera    
Wijesekera   
Gomes    
Warnakulasuriya    
Colombo    
Saparamadu  
Nonis  
Manamperi  
De costa    
Navaratne  
Vidanapathirana  
Croos          
Adhikari    
Salgado    
Kurukulasuriya       
Ratnam      
Loganathan  
Basnayaka                    
Maddumage  
Chandimal      
Pinto          
Manohara  
Peries    
Wasala  
Malinda  
Colombage    
Abeywardena  
Somasundara       
Don 
Mahalinga      
Antony    
Ramesh  
Balachandra    
Mapa  
Mahendra        
Jagoda 


from __future__ import unicode_literals
from os.path import abspath, join, dirname
import random


__title__ = 'names'
__version__ = '0.3.0'
__author__ = 'Trey Hunner'
__license__ = 'MIT'


full_path = lambda filename: abspath(join(dirname(__file__), filename))


FILES = {
    'first:male': full_path('dist.male.py'),
    'first:female': full_path('dist.female.py'),
    'last': full_path('dist.all.py'),
}


def get_name(filename):
    selected = random.random() * 90
    with open(filename) as name_file:
        for line in name_file:
            name, _, cummulative, _ = line.split()
            if float(cummulative) > selected:
                return name
    return ""  # Return empty string if file is empty


def get_first_name(gender=None):
    if gender not in ('male', 'female'):
        gender = random.choice(('male', 'female'))
    return get_name(FILES['first:%s' % gender]).capitalize()


def get_last_name():
    return get_name(FILES['last']).capitalize()


def get_full_name(gender=None):
    return "{0} {1}".format(get_first_name(gender), get_last_name())



Sasidnu 
Supun 
Dasun 
Pathum 
Dilshan
Sampath
Kasun
Chaminda
Dananjaya
Malinga
Sanath
Mahela
Anjolo
Upun
Sugath
Josop
Kusal
Akila
Chatura
Malith
Amila
Thilak
Nuwan
Prabath
Nipuna
Kavidu
Raveen
Krishan
Eranda
Kasun
Tharindu
Supun
Pasindu
Lahiru
Isuru
Gayan
Chathura
Thilina
Shehan
Ravindu
Sandun
Tharaka
Sanjeewa
Ishara
Buddhika
Amila
Hasitha
Sampath
Sahan
Sachintha
Ruwan
Roshan
Aruna
Ashan
Nuwan
Channa
Duminda
Hashan
Chamath
Rajitha
Akila
Sumudu
Induwara
Dinesh
Ranga
Kavindu
Shan
Anjana
Kevin
Sasindu
Chathuranga
Amal
Danushka
Mahesh
Asanka
Janitha
Heshan
Dilshan
Tharanga
Chanaka
Sachin
Nishan
Thushara
Samith
Gihan
Pradeep
Lakshan
Sameera
Chinthaka
Manoj
Sasun
Rehan
Indika
Janith
Sanjaya
Ashen
Imran
Deshan
Dulaj
Sajith
Hasith
Shashin
Naveen
Chanuka
Ravi
Shanaka
Rahmath Ali
Yohan
Dilan
Ananda
Kusal
Sachith
Darshana
Sithija
Lakmal
Harsha
Chamara
Shanuka
Maduranga
Khaalid
Malindu
Ayesh
Udula
Uvindu
Muditha
Udana
Suranga
Chiran
Sasith



from setuptools import setup, find_packages
 
classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Education',
  'Operating System :: Microsoft :: Windows :: Windows 10',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='iiyo',
  version='1.0.5',
  description='iiyo is Sinhala Prastha Pirulu Theravili, Thun theravili Sinhalen, Sinhala Random Name genarate ',
  long_description_content_type="text/markdown",
  long_description=open('README.md').read() + '\n\n' + open('CHANGELOG.txt').read(),
  package_data={'iiyo': ['*.txt', '*.py']},
  include_package_data=True,
  url='https://github.com/dotLK/iiyo',  
  author='https://github.com/dotLK',
  author_email='',
  license='MIT', 
  classifiers=classifiers,
  keywords='iiyo,Sinhala Prastha Pirulu, Theravili , Thun theravili sinhalen,random_name_generator,name-generator', 
  packages=find_packages(),
  install_requires=[''] 
)



sadasiri Niwasa 12/A
word Place 401 2/A
Amal Niwasa 1st Lane
27 Z/1 New Road
Wewa Rauma para 
Lake Road 4/5
Main Road
Cross Road
Temple Road
28/1 Pansala Para
School Road
Star Apatment
Sir Chitthampalam A Gardiner Mawatha
711-2880 Nulla St.
606-3727 Ullamcorper. Street
Ap 867-859 Sit Rd.
San Antonio MI 47096
Ap 651-8679 Sodales Av.
P.O. Box 929 4189 Nunc Road
Erie Rhode Island 24975
778-9383 Suspendisse Av.
P.O. Box 147 2546 Sociosqu Rd.










def colombo(num):
    match num:        
        case 1:
            return "Kotuwa"
        case 2:
            return "Kompacha Vidiya"
        case 3:
            return "Kollupitiya"
        case 4:
            return "Bambalapitiya"
        case 5:
            return "Hawlok Town"
        case 6:
            return "Wellawaththa"
        case 7:
            return "Kuruduwaththa"
        case 8:
            return "Dematagoda"
        case 9:
            return "Borella"
        case 10:
            return "Maradana"
        case 11:
            return "Pitakotuwa"
        case 12:
            return "Aluthkade"
        case 13:
            return "Kotchtchikade"
        case 14:
            return "Grandpass"
        case 15:
            return "Mattakkuliya"
        case default:
            return "Nothing"




